clear all

% Load file with extreme response for 20 3-hours simulation with different
% seeds, for both static and dynamic analysis
load extreme_values_double.txt

% Order the extreme values in two vectors
Extremes_stat = extreme_values_double(:,2);
Extremes_dyn = extreme_values_double(:,3);

% Calculating sample distribution F_stat
Extremes_stat = sort(Extremes_stat);
Extremes_stat = Extremes_stat';
for i = 1:length(Extremes_stat)
F_stat(i) = i/(1+length(Extremes_stat)); 
end
% Regression analysis for data plotted in Gubel paper
Y_stat = -log(-log(F_stat));
[r_stat,m_stat,b_stat] = regression(Extremes_stat,Y_stat);
x_stat = 0.016:0.0001:0.025;
reg_stat = b_stat+m_stat*x_stat;  %Regression line static analysis

% Find Gumber parameters
beta_stat = 1/m_stat;
alpha_stat = -b_stat*beta_stat;

%Calculate 100 anual probability response
r_stat_100 = alpha_stat - beta_stat*log(-log(0.9));

% Calculating sample distribution F_dyn
Extremes_dyn = sort(Extremes_dyn);
Extremes_dyn = Extremes_dyn';
for i = 1:length(Extremes_dyn)
F_dyn(i) = i/(1+length(Extremes_dyn)); 
end

% Regression analysis for data plotted in Gubel paper
Y_dyn = -log(-log(F_dyn));
[r_dyn,m_dyn,b_dyn] = regression(Extremes_dyn,Y_dyn);
x_dyn = 0.016:0.0001:0.025;
reg_dyn = b_dyn+m_dyn*x_dyn; %Regression line dynamic analysis

% Find Gumber parameters
beta_dyn = 1/m_dyn;
alpha_dyn = -b_dyn*beta_dyn;

%Calculate 100 anual probability response
r_dyn_100 = alpha_dyn -beta_dyn*log(-log(0.9));

% Plot the data together with the regression lines
plot(Extremes_stat,Y_stat,'r*')
hold on
plot(Extremes_dyn,Y_dyn,'*')
plot(x_stat,reg_stat)
plot(x_dyn,reg_dyn)
grid on
xlabel('Displacement')
ylabel('-ln(-ln(F(x))')
legend('Data from static analysis','Data from dynamic analysis',...
'Regression line from static analysis','Regression line from dynamic analysis')